@@ -96,8 +96,8 @@ qint32 OperationRunner::numJobs() const
 {
     qint32 result = 0;
 
-    foreach(const Operation * op,  operationStack().operations())
-    result += op->jobs().size();
+    for (const auto &op :  operationStack().operations())
+        result += op->jobs().size();
 
     return result;
 }
