@@ -44,7 +44,7 @@ public:
 
     qint64 readUsedCapacity(const QString& deviceNode) const override;
     bool check(Report& report, const QString& deviceNode) const override;
-    bool create(Report& report, const QString& deviceNode) const override;
+    bool create(Report& report, const QString& deviceNode) override;
     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
     bool updateUUID(Report& report, const QString& deviceNode) const override;
@@ -79,6 +79,9 @@ public:
     CommandSupportType supportSetLabel() const override {
         return m_SetLabel;
     }
+    CommandSupportType supportSetLabelOnline() const override {
+        return m_SetLabel;
+    }
     CommandSupportType supportUpdateUUID() const override {
         return m_UpdateUUID;
     }
