@@ -133,6 +133,7 @@ public:
     QString readUUID(const QString& deviceNode) const override;
     bool updateUUID(Report& report, const QString& deviceNode) const override;
     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
+    bool resizeOnline(Report& report, const QString& deviceNode, const QString& mountPoint, qint64 length) const override;
     QString readLabel(const QString& deviceNode) const override;
     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
 
@@ -171,16 +172,17 @@ public:
     void getLuksInfo(const QString& deviceNode);
 
     FileSystem* innerFS() const { return m_innerFs; }; // avoid calling this unless necessary
+    QString outerUuid() const;
 
-    QString mapperName() const { return m_MapperName; };
-    QString cipherName() const { return m_CipherName; };
-    QString cipherMode() const { return m_CipherMode; };
-    QString hashName() const { return m_HashName; };
-    qint64 keySize() const { return m_KeySize; };
-    qint64 payloadOffset() const { return m_PayloadOffset; };
+    QString mapperName() const { return m_MapperName; }
+    QString cipherName() const { return m_CipherName; }
+    QString cipherMode() const { return m_CipherMode; }
+    QString hashName() const { return m_HashName; }
+    qint64 keySize() const { return m_KeySize; }
+    qint64 payloadOffset() const { return m_PayloadOffset; }
 
     static bool canEncryptType(FileSystem::Type type);
-    static void initLUKS(FileSystem* fs);
+    void initLUKS();
 
 protected:
     virtual QString readOuterUUID(const QString& deviceNode) const;
@@ -214,6 +216,7 @@ private:
     QString m_HashName;
     qint64 m_KeySize;
     qint64 m_PayloadOffset;
+    QString m_outerUuid;
 };
 }
 
