@@ -44,9 +44,10 @@ public:
 
     qint64 readUsedCapacity(const QString& deviceNode) const override;
     bool check(Report& report, const QString& deviceNode) const override;
-    bool create(Report& report, const QString& deviceNode) const override;
+    bool create(Report& report, const QString& deviceNode) override;
     bool copy(Report& report, const QString&, const QString&) const override;
     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
+    bool resizeOnline(Report& report, const QString& deviceNode, const QString& mountPoint, qint64 length) const override;
     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
 
     CommandSupportType supportGetUsed() const override {
@@ -61,6 +62,9 @@ public:
     CommandSupportType supportGrow() const override {
         return m_Grow;
     }
+    CommandSupportType supportGrowOnline() const override {
+        return m_Grow;
+    }
     CommandSupportType supportMove() const override {
         return m_Move;
     }
