@@ -47,7 +47,7 @@ bool SetFileSystemLabelJob::run(Report& parent)
     // just ignore the request and say all is well. This helps in operations because
     // we don't have to check for support to avoid having a failed job.
     if (partition().fileSystem().supportSetLabel() == FileSystem::cmdSupportNone)
-        report->line() << xi18nc("@info/plain", "File system on partition <filename>%1</filename> does not support setting labels. Job ignored.", partition().deviceNode());
+        report->line() << xi18nc("@info:progress", "File system on partition <filename>%1</filename> does not support setting labels. Job ignored.", partition().deviceNode());
     else if (partition().fileSystem().supportSetLabel() == FileSystem::cmdSupportFileSystem) {
         rval = partition().fileSystem().writeLabel(*report, partition().deviceNode(), label());
 
@@ -62,5 +62,5 @@ bool SetFileSystemLabelJob::run(Report& parent)
 
 QString SetFileSystemLabelJob::description() const
 {
-    return xi18nc("@info/plain", "Set the file system label on partition <filename>%1</filename> to \"%2\"", partition().deviceNode(), label());
+    return xi18nc("@info:progress", "Set the file system label on partition <filename>%1</filename> to \"%2\"", partition().deviceNode(), label());
 }
