@@ -70,13 +70,13 @@ bool SetPartFlagsJob::run(Report& parent)
             if (backendPartition) {
                 quint32 count = 0;
 
-                foreach(const PartitionTable::Flag & f, PartitionTable::flagList()) {
+                for (const auto &f : PartitionTable::flagList()) {
                     emit progress(++count);
 
                     const bool state = (flags() & f) ? true : false;
 
                     if (!backendPartition->setFlag(*report, f, state)) {
-                        report->line() << xi18nc("@info/plain", "There was an error setting flag %1 for partition <filename>%2</filename> to state %3.", PartitionTable::flagName(f), partition().deviceNode(), state ? i18nc("@info/plain flag turned on, active", "on") : i18nc("@info/plain flag turned off, inactive", "off"));
+                        report->line() << xi18nc("@info:progress", "There was an error setting flag %1 for partition <filename>%2</filename> to state %3.", PartitionTable::flagName(f), partition().deviceNode(), state ? xi18nc("@info:progress flag turned on, active", "on") : xi18nc("@info:progress flag turned off, inactive", "off"));
 
                         rval = false;
                     }
@@ -84,18 +84,18 @@ bool SetPartFlagsJob::run(Report& parent)
 
                 delete backendPartition;
             } else
-                report->line() << xi18nc("@info/plain", "Could not find partition <filename>%1</filename> on device <filename>%2</filename> to set partition flags.", partition().deviceNode(), device().deviceNode());
+                report->line() << xi18nc("@info:progress", "Could not find partition <filename>%1</filename> on device <filename>%2</filename> to set partition flags.", partition().deviceNode(), device().deviceNode());
 
             if (rval)
                 backendPartitionTable->commit();
 
             delete backendPartitionTable;
         } else
-            report->line() << xi18nc("@info/plain", "Could not open partition table on device <filename>%1</filename> to set partition flags for partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+            report->line() << xi18nc("@info:progress", "Could not open partition table on device <filename>%1</filename> to set partition flags for partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
 
         delete backendDevice;
     } else
-        report->line() << xi18nc("@info/plain", "Could not open device <filename>%1</filename> to set partition flags for partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+        report->line() << xi18nc("@info:progress", "Could not open device <filename>%1</filename> to set partition flags for partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
 
     if (rval)
         partition().setFlags(flags());
@@ -108,7 +108,7 @@ bool SetPartFlagsJob::run(Report& parent)
 QString SetPartFlagsJob::description() const
 {
     if (PartitionTable::flagNames(flags()).size() == 0)
-        return xi18nc("@info/plain", "Clear flags for partition <filename>%1</filename>", partition().deviceNode());
+        return xi18nc("@info:progress", "Clear flags for partition <filename>%1</filename>", partition().deviceNode());
 
-    return xi18nc("@info/plain", "Set the flags for partition <filename>%1</filename> to \"%2\"", partition().deviceNode(), PartitionTable::flagNames(flags()).join(QStringLiteral(",")));
+    return xi18nc("@info:progress", "Set the flags for partition <filename>%1</filename> to \"%2\"", partition().deviceNode(), PartitionTable::flagNames(flags()).join(QStringLiteral(",")));
 }
