@@ -93,10 +93,10 @@ bool CreatePartitionTableOperation::execute(Report& parent)
 */
 bool CreatePartitionTableOperation::canCreate(const Device* device)
 {
-    return device != nullptr && (device->partitionTable() == nullptr || !device->partitionTable()->isChildMounted());
+    return (device != nullptr) && (device->partitionTable() == nullptr || !device->partitionTable()->isChildMounted()) && (device->type() != Device::LVM_Device);
 }
 
 QString CreatePartitionTableOperation::description() const
 {
-    return xi18nc("@info/plain", "Create a new partition table (type: %1) on <filename>%2</filename>", partitionTable()->typeName(), targetDevice().deviceNode());
+    return xi18nc("@info:status", "Create a new partition table (type: %1) on <filename>%2</filename>", partitionTable()->typeName(), targetDevice().deviceNode());
 }
