@@ -20,12 +20,12 @@
 
 #define REPORT__H
 
-#include "../util/libpartitionmanagerexport.h"
+#include "util/libpartitionmanagerexport.h"
 
 #include <QObject>
 #include <QList>
 #include <QString>
-#include <qglobal.h>
+#include <QtGlobal>
 
 class ReportLine;
 
